==> merchant-base-0.5.52-RELEASE-sources.jar: com/rocogz/merchant/request/customer/goods/MerchantCustomerGoodsSearchReq.java <==
package com.rocogz.merchant.request.customer.goods;

import com.rocogz.merchant.entity.customer.goods.MerchantIssuingBodyCustomerGoods;
import lombok.Data;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.util.List;

/**
 * @author djt
 * @date 2021/2/3
 */
@Data
@Accessors(chain = true)
public class MerchantCustomerGoodsSearchReq implements Serializable {

    /**
     * 需要过滤的产品编号列表，2021-11-18 新增
     */
    private String productCodeList;

    /**
     * 发放主体编号列表，2021-11-10 新增
     */
    private List<String> issuingBodyCodeList;


    /**
     * 查询类型
     */
    private String eQueryType;

    /**
     * 合作客户编号
     */
    private String customerCode;


    /**
     * 合作客户编号列表
     */
    private List<String> customerCodeList;

    /**
     * 合作客户产品编号
     */
    private String code;

    /**
     * 合作客户产品codes
     */
    private List<String> customerGoodCodeList;

    /**
     * 产品名称
     */
    private String name;

    /**
     * 采购方式
     */
    private String purchaseWay;

    /**
     * 产品类型
     */
    private String goodCategory;

    /**
     * 代理商产品编号
     */
    private String agentGoodsCode;

    /**
     * 平台产品编号
     */
    private String merchantGoodsCode;

    /**
     * 代理产品编号
     */
    private String supplierProductCode;

    /**
     * 产品状态
     */
    private String status;

    /**
     * 排序字段
     * 已知：当issuingBodyGoodsStatus 使用在清单列表中弹窗选择产品弹窗的排序
     */
    private String sortProp;

    /**
     * 是否启用库存
     */
    private String whetherNeedStock;

    /**
     * 排序方式
     */
    private String sortType;

    /**
     * 产品类型
     */
    private String goodsType;

    /**
     * 产品类型集合
     */
    private List<String> goodsTypeList;

    /**
     * 页大小
     */
    private Integer limit=10 ;

    /**
     * 当前页
     */
    private Integer page=1 ;

    /**
     * 是否开始分页
     */
    private Boolean enablePage=false;

    /**
     * 需要列表
     * 这个是在主体页签 主体可发放产品配置主体产品时
     * 因为调用的原来的分页接口，里面写的是要分页，但是js中传递的limit=10000 实际只能查询500
     * 为了在那个方法中将enablePage清楚下，再增加下这个标记位置Y/N 控制
     */
    private String notPage;



    public enum EQueryType{
        /**
         * ADMIN后台 主体权益商品-发放主体专用
         */
        ADMIN_ISSUING_LIST,
        /**
         * ADMIN后台 权益商品-系统专用
         */
        ADMIN_SYSTEM_LIST
    }


    /**
     * 发放主体产品的状态:
     * @see MerchantIssuingBodyCustomerGoods#status
     * 上架/下架  能发放的产品状态 需要是双上架：合作客户产品上架，发放主体产品上上架
     */
    private String issuingBodyGoodsStatus;

}

==> merchant-base-0.5.60-RELEASE-sources.jar: com/rocogz/merchant/request/customer/goods/MerchantCustomerGoodsSearchReq.java <==
package com.rocogz.merchant.request.customer.goods;

import com.rocogz.merchant.entity.customer.goods.MerchantIssuingBodyCustomerGoods;
import lombok.Data;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.util.List;

/**
 * @author djt
 * @date 2021/2/3
 */
@Data
@Accessors(chain = true)
public class MerchantCustomerGoodsSearchReq implements Serializable {

    /**
     * 需要过滤的产品编号列表，2021-11-18 新增
     */
    private String productCodeList;

    /**
     * 发放主体编号列表，2021-11-10 新增
     */
    private List<String> issuingBodyCodeList;


    /**
     * 查询类型
     */
    private String eQueryType;

    /**
     * 合作客户编号
     */
    private String customerCode;


    /**
     * 合作客户编号列表
     */
    private List<String> customerCodeList;

    /**
     * 合作客户产品编号
     */
    private String code;

    /**
     * 合作客户产品codes
     */
    private List<String> customerGoodCodeList;

    /**
     * 产品名称
     */
    private String name;

    /**
     * 采购方式
     */
    private String purchaseWay;

    /**
     * 产品类型
     */
    private String goodCategory;

    /**
     * 代理商产品编号
     */
    private String agentGoodsCode;

    /**
     * 平台产品编号
     */
    private String merchantGoodsCode;

    /**
     * 代理产品编号
     */
    private String supplierProductCode;

    /**
     * 产品状态
     */
    private String status;

    /**
     * 排序字段
     * 已知：当issuingBodyGoodsStatus 使用在清单列表中弹窗选择产品弹窗的排序
     */
    private String sortProp;

    /**
     * 是否启用库存
     */
    private String whetherNeedStock;

    /**
     * 排序方式
     */
    private String sortType;

    /**
     * 产品类型
     */
    private String goodsType;

    /**
     * 产品类型集合
     */
    private List<String> goodsTypeList;

    /**
     * 页大小
     */
    private Integer limit=10 ;

    /**
     * 当前页
     */
    private Integer page=1 ;

    /**
     * 是否开始分页
     */
    private Boolean enablePage=false;

    /**
     * 需要列表
     * 这个是在主体页签 主体可发放产品配置主体产品时
     * 因为调用的原来的分页接口，里面写的是要分页，但是js中传递的limit=10000 实际只能查询500
     * 为了在那个方法中将enablePage清楚下，再增加下这个标记位置Y/N 控制
     */
    private String notPage;



    public enum EQueryType{
        /**
         * ADMIN后台 主体权益商品-发放主体专用
         */
        ADMIN_ISSUING_LIST,
        /**
         * ADMIN后台 权益商品-系统专用
         */
        ADMIN_SYSTEM_LIST
    }


    /**
     * 发放主体产品的状态:
     * @see MerchantIssuingBodyCustomerGoods#status
     * 上架/下架  能发放的产品状态 需要是双上架：合作客户产品上架，发放主体产品上上架
     */
    private String issuingBodyGoodsStatus;

    /**
     * 业务类型：主体中业务类型
     *
     * 主体 如果 该业务类型仅可发放已添加的专用产品：Y 再传递这个值
     */
    private String businessTypeCode;

    /**
     * 排除掉的 用在主体可发放产品添加 专用产品的弹窗中
     */
    private String excludeBusinessTypeCode;

    /**
     * 发放主体编号
     */
    private String issuingBodyCode;

}
